@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.2.8
+# Version   : 0.2.10
 
 import  numpy                   as      np
 import  plotly.graph_objects    as      go
@@ -481,10 +481,6 @@ class AFM:
 
         self.measurements = self.approach_raw.shape[0]
 
-        list_len = [len(i) for i in self.approach_raw]
-
-            
-
     def plot_raw(
         self,
         curve_number = 1
@@ -505,8 +501,8 @@ class AFM:
 
         else:
             fig = go.Figure()
-            fig.add_trace(go.Scatter(y = self.approach_raw[:,curve_number], x = self.z_approach_raw[:,curve_number], mode='lines', name = 'Approach curve (raw)'))
-            fig.add_trace(go.Scatter(y = self.retract_raw[:,curve_number], x = self.z_withdraw_raw[:,curve_number], mode='lines', name = 'Retract curve (raw)'))
+            fig.add_trace(go.Scatter(y = self.approach_raw[curve_number], x = self.z_approach_raw[curve_number], mode='lines', name = 'Approach curve (raw)'))
+            fig.add_trace(go.Scatter(y = self.retract_raw[curve_number], x = self.z_withdraw_raw[curve_number], mode='lines', name = 'Retract curve (raw)'))
             fig.update_layout(
                 yaxis_title_text='Force (nN)',
                 xaxis_title_text='Piezo position (nm)',
@@ -574,21 +570,28 @@ class AFM:
                 blank[:] = np.nan
 
                 adjusted_approach = np.append(adjusted_approach, blank)
-                adjusted_retract =  np.append(adjusted_retract, blank)
                 _z_a = np.append(_z_a, blank)
-                _z_w = np.append(_z_w, blank)
+
+                if len(adjusted_retract) < self.samps_line:
+                    blank = np.empty(self.samps_line - len(adjusted_approach))
+                    blank[:] = np.nan
+                    
+                    adjusted_retract =  np.append(adjusted_retract, blank)
+                    _z_w = np.append(_z_w, blank)
 
             if approach_dev < max_approach_noise and retract_dev < max_retract_noise:
-                self.approach[:,i] = adjusted_approach
-                self.retract[:,i] = adjusted_retract
 
                 if self.file_name[-3:] != 'nid':
                     self.z_approach[:,i] = _z
                     self.z_withdraw[:,i] = _z
+                    self.approach[:,i] = adjusted_approach
+                    self.retract[:,i] = adjusted_retract
 
                 else:
-                    self.z_approach[:,i] = _z_a
-                    self.z_withdraw[:,i] = _z_w
+                    self.z_approach[:,i] = _z_a[::-1] * -1
+                    self.z_withdraw[:,i] = _z_w[::-1] * -1
+                    self.approach[:,i] = adjusted_approach[::-1]
+                    self.retract[:,i] = adjusted_retract[::-1]
 
                 i += 1
 
@@ -623,8 +626,9 @@ class AFM:
                 f = interp.interp1d(x,y)
                 intercept = f(0)
 
-                self.z_approach[:,i] = self.z_approach[:,i] - intercept
-                self.z_withdraw[:,i] = self.z_withdraw[:,i] - intercept
+                if np.isnan(intercept) == False:
+                    self.z_approach[:,i] = self.z_approach[:,i] - intercept
+                    self.z_withdraw[:,i] = self.z_withdraw[:,i] - intercept
 
             except:
                 print('WARNING: Could not locate contact point for curve number ', i, '. Consider checking baseline alignment.')
